# Generated by roxygen2: do not edit by hand

export(get_deps)
export(get_heritage)
export(get_heritage_ids)
export(get_heritage_layernames)
importFrom(happign,get_wfs)
importFrom(happign,intersects)
importFrom(httr2,req_method)
importFrom(httr2,req_perform)
importFrom(httr2,req_retry)
importFrom(httr2,req_timeout)
importFrom(httr2,request)
importFrom(httr2,resp_body_raw)
importFrom(httr2,resp_body_string)
importFrom(httr2,resp_status)
importFrom(jsonlite,toJSON)
importFrom(sf,st_bbox)
importFrom(sf,st_buffer)
importFrom(sf,st_cast)
importFrom(sf,st_centroid)
importFrom(sf,st_crs)
importFrom(sf,st_geometry)
importFrom(sf,st_geometry_type)
importFrom(sf,st_intersects)
importFrom(sf,st_is_empty)
importFrom(sf,st_is_valid)
importFrom(sf,st_join)
importFrom(sf,st_make_valid)
importFrom(sf,st_read)
importFrom(sf,st_set_crs)
importFrom(sf,st_sf)
importFrom(sf,st_transform)
importFrom(sf,st_union)
importFrom(sf,st_zm)
importFrom(utils,URLencode)
importFrom(utils,capture.output)
importFrom(utils,data)
importFrom(utils,unzip)
importFrom(xml2,read_xml)
importFrom(xml2,xml_find_all)
importFrom(xml2,xml_text)
