% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\docType{data}
\name{extdata_examples}
\alias{extdata_examples}
\title{Example files for testing}
\description{
These files are used internally for testing functions.
}
\keyword{internal}
