% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geo.R
\name{geo_shapefile_read}
\alias{geo_shapefile_read}
\title{Read and transform shapefile from a ZIP archive}
\usage{
geo_shapefile_read(zip_path, crs = 2154)
}
\arguments{
\item{zip_path}{\code{character}. Path to the ZIP archive to read.}

\item{crs}{\code{numeric} or \code{sf::st_crs} object. Target CRS to transform to.
Default is 2154 (Lambert-93).}
}
\value{
An \code{sf} object transformed to CRS:2154.
}
\description{
Extracts shapefiles from a ZIP archive, reads the shapefile found
in the "documents" folder into an \code{sf} object, and transforms it to
CRS:2154 (Lambert-93 projection for France), unless already in the target CRS.
}
\keyword{internal}
